@@ -5,6 +5,7 @@ import os
 import errno
 import unicodedata
 import string
+import getpass
 from mechanize import Browser
 from bs4 import BeautifulSoup
 
@@ -407,13 +408,16 @@ class AbsoluteURLGen(object):
 def main():
     # parse the commandline arguments
     parser = argparse.ArgumentParser(description='Download Coursera.org course videos/docs for offline use.')
-    parser.add_argument("-u", dest='username', type=str, help='coursera.org username')
+    parser.add_argument("-u", dest='username', type=str, required=True, help='coursera.org username')
     parser.add_argument("-p", dest='password', type=str, help='coursera.org password')
     parser.add_argument("-d", dest='target_dir', type=str, default=".", help='destination directory where everything will be saved')
     parser.add_argument('course_names', nargs="+", metavar='<course name>',
                         type=str, help='one or more course names (from the url)')
     args = parser.parse_args()
 
+    if not args.password:
+        args.password = getpass.getpass()
+
     # instantiate the downloader class
     d = CourseraDownloader(args.username,args.password)
 
